import { Component, Input, Output, EventEmitter } from '@angular/core';
import { Day } from 'dayspan';
import { DatePickerProvider } from '../providers/date-picker-provider';
import * as moment from 'moment';
var HTML_CODE = "\n<div>\n    <ion-item *ngIf=\"showView === 'calendar'\">\n        <ion-icon name=\"calendar\" item-start>\n        </ion-icon>\n        <button ion-button clear (click)=\"showMonthView()\" class=\"calendar-button\">\n            {{monthLabels[monthSelected-1]}}\n        </button>\n        <button ion-button clear (click)=\"showYearView()\" class=\"calendar-button\">\n            {{yearSelected}}\n        </button>\n\n        <span item-end>\n            <button ion-button clear (click)=\"previous()\">\n                <ion-icon name=\"ios-arrow-back\"></ion-icon>\n            </button>\n            <button ion-button clear (click)=\"next()\">\n                <ion-icon name=\"ios-arrow-forward\"></ion-icon>\n            </button>\n        </span>\n    </ion-item>\n\n    <ion-grid *ngIf=\"showView === 'calendar'\">\n        <ion-row>\n            <ion-col *ngFor=\"let daylabel of dayLabels\" text-center class=\"days-label\">\n                {{daylabel}}\n            </ion-col>\n        </ion-row>\n        <ion-row *ngFor=\"let week of weeks\">\n            <ion-col *ngFor=\"let day of week\" (click)=\"selectDay(day)\" [class.current-item]=\"isToday(day.dayOfMonth)\" [class.item-selected]=\"daySelected && day.dayIdentifier === daySelected.dayIdentifier\"\n                text-center>\n                <span [class.not-this-month]=\"!day.inCalendar\">{{day.dayOfMonth}}</span>\n            </ion-col>\n        </ion-row>\n    </ion-grid>\n\n    <ion-grid *ngIf=\"showView === 'month'\">\n        <ion-row justify-content-end>\n            <ion-col text-end>\n                <button ion-button icon-only clear (click)=\"resetView()\">\n                    <ion-icon name=\"close\"></ion-icon>\n                </button>\n            </ion-col>\n        </ion-row>\n        <ion-row>\n            <ion-col *ngFor=\"let monthLabel of monthLabels; let i = index\" [class.current-item]=\"i === currentMonth - 1\" [class.item-selected]=\"i === monthSelected - 1\"\n                class=\"months-label\" col-3 (click)=\"selectMonth(i+1)\" text-center>\n                {{monthLabel}}\n            </ion-col>\n        </ion-row>\n    </ion-grid>\n\n    <ion-grid *ngIf=\"showView === 'year'\">\n        <ion-row>\n            <ion-col col-10 text-center>\n                    <div>\n                        <button ion-button icon-only clear (click)=\"showPreviousYears()\">\n                            <ion-icon name=\"ios-arrow-back\"></ion-icon>\n                        </button>\n                        <button ion-button clear [disabled]=\"true\" class=\"year-range\">\n                            {{startYear}} to {{endYear}}\n                        </button>\n                    \n                        <button ion-button icon-only clear (click)=\"showNextYears()\">\n                            <ion-icon name=\"ios-arrow-forward\"></ion-icon>\n                        </button>\n                    </div>\n            </ion-col>\n            <ion-col col-2 text-center>\n                <button ion-button icon-only clear (click)=\"resetView()\">\n                    <ion-icon name=\"close\"></ion-icon>\n                </button>\n            </ion-col>\n        </ion-row> \n        <ion-row>\n            <ion-col *ngFor=\"let year of years\" [class.current-item]=\"year === currentYear\" [class.item-selected]=\"year === yearSelected\" class=\"months-label\"\n                col-3 (click)=\"selectYear(year)\" text-center>\n                {{year}}\n            </ion-col>\n        </ion-row>\n    </ion-grid>\n</div>\n";
var CSS_STYLE = "\ndate-picker-component {\n  .not-this-month {\n    color: #8b8b8b;\n  }\n\n  .item {\n      .item-inner {\n        border-bottom: none !important;\n      }\n    }\n\n  .days-label {\n    font-weight: 500;\n    font-size: 14px;\n  }\n\n  .months-label {\n    font-size: 15px;\n  }\n\n  .calendar-month-label {\n    font-weight: 500;\n    font-size: 16px;\n  }\n\n  .item-selected {\n    background: color($colors, primary);\n    color: color($colors, light) !important;\n  }\n\n  .current-item {\n    color: color($colors, secondary);\n  }\n\n  .forward-button {\n    float: right;\n  }\n\n  ion-icon {\n    font-size: 25px;\n  }\n\n  .year-range {\n    font-size: 15px;\n    font-weight: 550;\n    &.button[disabled] {\n      opacity: 1;\n      color: gray;\n    }\n  }\n\n  .calendar-button {\n    text-decoration: underline;\n    padding-right: 2px !important;\n    padding-left: 2px !important;\n  }\n}\n";
var DatePickerComponent = (function () {
    function DatePickerComponent(datePickerProvider) {
        this.datePickerProvider = datePickerProvider;
        this.monthLabels = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
        this.dayLabels = ['S', 'M', 'T', 'W', 'T', 'F', 'S'];
        this.onSelect = new EventEmitter();
        this.showView = 'calendar';
        this.yearSelected = new Date().getFullYear();
        this.monthSelected = new Date().getMonth() + 1;
        this.currentYear = new Date().getFullYear();
        this.currentMonth = new Date().getMonth() + 1;
        this.currentDay = new Date().getDate();
    }
    DatePickerComponent.prototype.ngOnInit = function () {
        this.initOptions();
        this.createCalendarWeeks();
    };
    DatePickerComponent.prototype.initOptions = function () {
        this.yearSelected = this.date ? this.date.getFullYear() : new Date().getFullYear();
        this.monthSelected = this.date ? this.date.getMonth() + 1 : new Date().getMonth() + 1;
        this.dayHighlighted = this.date ? Day.fromDate(this.date) : Day.today();
        if (this.date) {
            this.daySelected = this.dayHighlighted;
        }
    };
    DatePickerComponent.prototype.createCalendarWeeks = function () {
        this.weeks = this.datePickerProvider.generateCalendarWeeks(Day.fromMoment(moment(this.monthSelected + '-01-' + this.yearSelected, 'MM-DD-YYYY')));
    };
    DatePickerComponent.prototype.previous = function () {
        if (this.monthSelected === 1) {
            this.monthSelected = 12;
            this.yearSelected--;
        }
        else {
            this.monthSelected--;
        }
        this.createCalendarWeeks();
    };
    DatePickerComponent.prototype.next = function () {
        if (this.monthSelected === 12) {
            this.monthSelected = 1;
            this.yearSelected++;
        }
        else {
            this.monthSelected++;
        }
        this.createCalendarWeeks();
    };
    DatePickerComponent.prototype.confirmDay = function (day) {
        this.onSelect.emit(day.toDate());
    };
    DatePickerComponent.prototype.selectDay = function (day) {
        var _this = this;
        this.daySelected = day;
        setTimeout(function () {
            _this.confirmDay(day);
        }, 200);
    };
    DatePickerComponent.prototype.showMonthView = function () {
        this.showView = 'month';
        "";
    };
    DatePickerComponent.prototype.showYearView = function () {
        this.showView = 'year';
        var startYear = this.yearSelected - 10;
        if (startYear % 10 !== 0) {
            startYear = startYear - (startYear % 10);
        }
        var endYear = startYear + 19;
        this.startYear = startYear;
        this.endYear = endYear;
        this.generateYears();
    };
    DatePickerComponent.prototype.generateYears = function () {
        this.years = [];
        for (var i = this.startYear; i <= this.endYear; i++) {
            this.years.push(i);
        }
    };
    DatePickerComponent.prototype.showPreviousYears = function () {
        this.endYear = this.startYear - 1;
        this.startYear = this.endYear - 19;
        this.generateYears();
    };
    DatePickerComponent.prototype.showNextYears = function () {
        this.startYear = this.endYear + 1;
        this.endYear = this.startYear + 19;
        this.generateYears();
    };
    DatePickerComponent.prototype.selectMonth = function (month) {
        var _this = this;
        this.monthSelected = month;
        this.createCalendarWeeks();
        setTimeout(function () {
            _this.showView = 'calendar';
        }, 200);
    };
    DatePickerComponent.prototype.selectYear = function (year) {
        var _this = this;
        this.yearSelected = year;
        this.createCalendarWeeks();
        setTimeout(function () {
            _this.showView = 'calendar';
        }, 200);
    };
    DatePickerComponent.prototype.resetView = function () {
        this.showView = 'calendar';
    };
    DatePickerComponent.prototype.isToday = function (day) {
        return this.yearSelected === this.currentYear && this.monthSelected === this.currentMonth && this.currentDay === day;
    };
    DatePickerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ionic-calendar-date-picker',
                    template: HTML_CODE,
                    styles: [CSS_STYLE]
                },] },
    ];
    /** @nocollapse */
    DatePickerComponent.ctorParameters = function () { return [
        { type: DatePickerProvider, },
    ]; };
    DatePickerComponent.propDecorators = {
        "monthLabels": [{ type: Input },],
        "dayLabels": [{ type: Input },],
        "date": [{ type: Input },],
        "onSelect": [{ type: Output },],
    };
    return DatePickerComponent;
}());
export { DatePickerComponent };
//# sourceMappingURL=date-picker-component.js.map